Class: ChangeHealthcare::ProfessionalClaims::SwaggerClient::FormIdentification

Inherits:
Object
  • Object
show all
Defined in:
lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FormIdentification

Initializes the object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 65

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.transform_keys(&:to_sym)

  self.form_identifier = attributes[:formIdentifier] if attributes.key?(:formIdentifier)

  self.form_type_code = attributes[:formTypeCode] if attributes.key?(:formTypeCode)

  if attributes.key?(:supportingDocumentation) && (value = attributes[:supportingDocumentation]).is_a?(Array)
    self.supporting_documentation = value
  end
end

Instance Attribute Details

#form_identifierObject

Returns the value of attribute form_identifier.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 19

def form_identifier
  @form_identifier
end

#form_type_codeObject

Allowed Values are:'AS' Form Type Code, 'UT' Centers for Medicare and Medicaid Services (CMS) Durable Medical Equipment Regional Carrier (DMERC) Certificate of Medical Necessity (CMN) Forms



22
23
24
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 22

def form_type_code
  @form_type_code
end

#supporting_documentationObject

Returns the value of attribute supporting_documentation.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 19

def supporting_documentation
  @supporting_documentation
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 46

def self.attribute_map
  {
    form_identifier: :formIdentifier,
    form_type_code: :formTypeCode,
    supporting_documentation: :supportingDocumentation
  }
end

.swagger_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 55

def self.swagger_types
  {
    form_identifier: :String,
    form_type_code: :String,
    supporting_documentation: :'Array<SupportingDocumentation>'
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



109
110
111
112
113
114
115
116
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 109

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    form_identifier == other.form_identifier &&
    form_type_code == other.form_type_code &&
    supporting_documentation == other.supporting_documentation
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 157

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SwaggerClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 224

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 133

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        send("#{key}=", attributes[self.class.attribute_map[key]].map do |v|
                          _deserialize(Regexp.last_match(1), v)
                        end)
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


120
121
122
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 120

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



126
127
128
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 126

def hash
  [form_identifier, form_type_code, supporting_documentation].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



82
83
84
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 82

def list_invalid_properties
  []
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



203
204
205
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 203

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    next if value.nil?

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



197
198
199
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 197

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



88
89
90
91
92
93
# File 'lib/change_healthcare/professional_claims/swagger_client/models/form_identification.rb', line 88

def valid?
  form_type_code_validator = EnumAttributeValidator.new('String', %w[AS UT])
  return false unless form_type_code_validator.valid?(@form_type_code)

  true
end