Class: ChangeHealthcare::ProfessionalClaims::SwaggerClient::ReportInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReportInformation

Initializes the object



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.transform_keys(&:to_sym)

  self.attachment_control_number = attributes[:attachmentControlNumber] if attributes.key?(:attachmentControlNumber)

  self.attachment_report_type_code = attributes[:attachmentReportTypeCode] if attributes.key?(:attachmentReportTypeCode)

  self.attachment_transmission_code = attributes[:attachmentTransmissionCode] if attributes.key?(:attachmentTransmissionCode)
end

Instance Attribute Details

#attachment_control_numberObject

Returns the value of attribute attachment_control_number.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 19

def attachment_control_number
  @attachment_control_number
end

#attachment_report_type_codeObject

Allowed Values are: '03' Report Justifying Treatment Beyond Utilization Guidelines, '04' Drugs Administered, '05' Treatment Diagnosis, '06' Initial Assessment, '07' Functional Goals, '08' Plan of Treatment, '09' Progress Report, '10' Continued Treatment, '11' Chemical Analysis, '13' Certified Test Report, '15' Justification for Admission, '21' Recovery Plan, 'A3' Allergies/Sensitivities Document, 'A4' Autopsy Report, 'AM' Ambulance Certification, 'AS' Admission Summary, 'B2' Prescription, 'B3' Physician Order, 'B4' Referral Form, 'BR' Benchmark Testing Results, 'BS' Baseline, 'BT' Blanket Test Results, 'CB' Chiropractic Justification, 'CK' Consent Form(s), 'CT' Certification, 'D2' Drug Profile Document, 'DA' Dental Models, 'DB' Durable Medical Equipment Prescription, 'DG' Diagnostic Report, 'DJ' Discharge Monitoring Report, 'DS' Discharge Summary, 'EB' Explanation of Benefits (Coordination of Benefits or Medicare Secondary Payor), 'HC' Health Certificate, 'HR' Health Clinic Records, 'I5' Immunization Record,'IR' State School Immunization Records, 'LA' Laboratory Results, 'M1' Medical Record Attachment, 'MT' Models, 'NM Nursing Notes', 'OB' Operative Note, 'OC' Oxygen Content Averaging Report, 'OD' Orders and Treatments Document, 'OE' Objective Physical Examination (including vital signs) Document, 'OX' Oxygen Therapy Certification, 'OZ' Support Data for Claim, 'P4' Pathology Report, 'P5' Patient Medical History Document, 'PE' Parenteral or Enteral Certification, 'PN' Physical Therapy Notes, 'PO' Prosthetics or Orthotic Certification, 'PQ' Paramedical Results, 'PY' Physician’s Report, 'PZ' Physical Therapy Certification, 'RB' Radiology Films, 'RR' Radiology Reports, 'RT' Report of Tests and Analysis Report, 'RX' Renewable Oxygen Content Averaging Report, 'SG' Symptoms Document, 'V5' Death Notification, 'XP' Photographs



22
23
24
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 22

def attachment_report_type_code
  @attachment_report_type_code
end

#attachment_transmission_codeObject

Allowed Values are: 'AA' Available on Request at Provider Site, 'BM' By Mail, 'EL' Electronically Only, 'EM' E-Mail, 'FT' File Transfer, 'FX' By Fax



25
26
27
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 25

def attachment_transmission_code
  @attachment_transmission_code
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 49

def self.attribute_map
  {
    attachment_control_number: :attachmentControlNumber,
    attachment_report_type_code: :attachmentReportTypeCode,
    attachment_transmission_code: :attachmentTransmissionCode
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 58

def self.swagger_types
  {
    attachment_control_number: :String,
    attachment_report_type_code: :String,
    attachment_transmission_code: :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



130
131
132
133
134
135
136
137
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 130

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    attachment_control_number == other.attachment_control_number &&
    attachment_report_type_code == other.attachment_report_type_code &&
    attachment_transmission_code == other.attachment_transmission_code
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 178

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SwaggerClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 245

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 154

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        send("#{key}=", attributes[self.class.attribute_map[key]].map do |v|
                          _deserialize(Regexp.last_match(1), v)
                        end)
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


141
142
143
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 141

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



147
148
149
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 147

def hash
  [attachment_control_number, attachment_report_type_code, attachment_transmission_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



83
84
85
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 83

def list_invalid_properties
  []
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



224
225
226
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 224

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    next if value.nil?

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



218
219
220
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 218

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/change_healthcare/professional_claims/swagger_client/models/report_information.rb', line 89

def valid?
  attachment_report_type_code_validator = EnumAttributeValidator.new('String',
                                                                     %w[03 04 05 06 07 08 09 10 11 13 15 21 A3 A4 AM AS B2 B3 B4 BR BS BT CB CK CT D2 DA DB DG DJ DS EB HC HR I5 IR LA M1
                                                                        MT NM OB OC OD OE OX OZ P4 P5 PE PN PO PQ PY PZ RB RR RT RX SG V5 XP])
  return false unless attachment_report_type_code_validator.valid?(@attachment_report_type_code)

  attachment_transmission_code_validator = EnumAttributeValidator.new('String',
                                                                      %w[AA BM EL EM FT FX])
  return false unless attachment_transmission_code_validator.valid?(@attachment_transmission_code)

  true
end