Class: ChangeHealthcare::ProfessionalClaims::SwaggerClient::ServiceLineReferenceInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ServiceLineReferenceInformation

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 52

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.transform_keys(&:to_sym)

  self.adjusted_repriced_line_item_reference_number = attributes[:adjustedRepricedLineItemReferenceNumber] if attributes.key?(:adjustedRepricedLineItemReferenceNumber)

  self.clinical_laboratory_improvement_amendment_number = attributes[:clinicalLaboratoryImprovementAmendmentNumber] if attributes.key?(:clinicalLaboratoryImprovementAmendmentNumber)

  self.immunization_batch_number = attributes[:immunizationBatchNumber] if attributes.key?(:immunizationBatchNumber)

  self.mammography_certification_number = attributes[:mammographyCertificationNumber] if attributes.key?(:mammographyCertificationNumber)

  if attributes.key?(:priorAuthorization) && (value = attributes[:priorAuthorization]).is_a?(Array)
    self.prior_authorization = value
  end

  if attributes.key?(:referralNumber) && (value = attributes[:referralNumber]).is_a?(Array)
    self.referral_number = value
  end

  self.referring_clia_number = attributes[:referringCliaNumber] if attributes.key?(:referringCliaNumber)

  self.repriced_line_item_reference_number = attributes[:repricedLineItemReferenceNumber] if attributes.key?(:repricedLineItemReferenceNumber)
end

Instance Attribute Details

#adjusted_repriced_line_item_reference_numberObject

Returns the value of attribute adjusted_repriced_line_item_reference_number.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 19

def adjusted_repriced_line_item_reference_number
  @adjusted_repriced_line_item_reference_number
end

#clinical_laboratory_improvement_amendment_numberObject

Returns the value of attribute clinical_laboratory_improvement_amendment_number.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 19

def clinical_laboratory_improvement_amendment_number
  @clinical_laboratory_improvement_amendment_number
end

#immunization_batch_numberObject

Returns the value of attribute immunization_batch_number.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 19

def immunization_batch_number
  @immunization_batch_number
end

#mammography_certification_numberObject

Returns the value of attribute mammography_certification_number.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 19

def mammography_certification_number
  @mammography_certification_number
end

#prior_authorizationObject

Returns the value of attribute prior_authorization.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 19

def prior_authorization
  @prior_authorization
end

#referral_numberObject

Returns the value of attribute referral_number.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 19

def referral_number
  @referral_number
end

#referring_clia_numberObject

Returns the value of attribute referring_clia_number.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 19

def referring_clia_number
  @referring_clia_number
end

#repriced_line_item_reference_numberObject

Returns the value of attribute repriced_line_item_reference_number.



19
20
21
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 19

def repriced_line_item_reference_number
  @repriced_line_item_reference_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 23

def self.attribute_map
  {
    adjusted_repriced_line_item_reference_number: :adjustedRepricedLineItemReferenceNumber,
    clinical_laboratory_improvement_amendment_number: :clinicalLaboratoryImprovementAmendmentNumber,
    immunization_batch_number: :immunizationBatchNumber,
    mammography_certification_number: :mammographyCertificationNumber,
    prior_authorization: :priorAuthorization,
    referral_number: :referralNumber,
    referring_clia_number: :referringCliaNumber,
    repriced_line_item_reference_number: :repricedLineItemReferenceNumber
  }
end

.swagger_typesObject

Attribute type mapping.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 37

def self.swagger_types
  {
    adjusted_repriced_line_item_reference_number: :String,
    clinical_laboratory_improvement_amendment_number: :String,
    immunization_batch_number: :String,
    mammography_certification_number: :String,
    prior_authorization: :'Array<PriorAuthorization>',
    referral_number: :'Array<String>',
    referring_clia_number: :String,
    repriced_line_item_reference_number: :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 93

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    adjusted_repriced_line_item_reference_number == other.adjusted_repriced_line_item_reference_number &&
    clinical_laboratory_improvement_amendment_number == other.clinical_laboratory_improvement_amendment_number &&
    immunization_batch_number == other.immunization_batch_number &&
    mammography_certification_number == other.mammography_certification_number &&
    prior_authorization == other.prior_authorization &&
    referral_number == other.referral_number &&
    referring_clia_number == other.referring_clia_number &&
    repriced_line_item_reference_number == other.repriced_line_item_reference_number
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 147

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SwaggerClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 214

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 123

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        send("#{key}=", attributes[self.class.attribute_map[key]].map do |v|
                          _deserialize(Regexp.last_match(1), v)
                        end)
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • to be compared

Returns:



109
110
111
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 109

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



115
116
117
118
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 115

def hash
  [adjusted_repriced_line_item_reference_number, clinical_laboratory_improvement_amendment_number,
   immunization_batch_number, mammography_certification_number, prior_authorization, referral_number, referring_clia_number, repriced_line_item_reference_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



81
82
83
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 81

def list_invalid_properties
  []
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



193
194
195
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 193

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    next if value.nil?

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



187
188
189
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 187

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



87
88
89
# File 'lib/change_healthcare/professional_claims/swagger_client/models/service_line_reference_information.rb', line 87

def valid?
  true
end