Class: ChangeHealthcare::ProfessionalClaims::SwaggerClient::ClaimContractInformation
- Inherits:
-
Object
- Object
- ChangeHealthcare::ProfessionalClaims::SwaggerClient::ClaimContractInformation
- Defined in:
- lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#contract_amount ⇒ Object
Returns the value of attribute contract_amount.
-
#contract_code ⇒ Object
Returns the value of attribute contract_code.
-
#contract_percentage ⇒ Object
Returns the value of attribute contract_percentage.
-
#contract_type_code ⇒ '01', ...
Allowed Values are:.
-
#contract_version_identifier ⇒ Object
Returns the value of attribute contract_version_identifier.
-
#terms_discount_percentage ⇒ Object
Returns the value of attribute terms_discount_percentage.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClaimContractInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ClaimContractInformation
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.transform_keys(&:to_sym) self.contract_amount = attributes[:contractAmount] if attributes.key?(:contractAmount) self.contract_code = attributes[:contractCode] if attributes.key?(:contractCode) self.contract_percentage = attributes[:contractPercentage] if attributes.key?(:contractPercentage) self.contract_type_code = attributes[:contractTypeCode] if attributes.key?(:contractTypeCode) self.contract_version_identifier = attributes[:contractVersionIdentifier] if attributes.key?(:contractVersionIdentifier) self.terms_discount_percentage = attributes[:termsDiscountPercentage] if attributes.key?(:termsDiscountPercentage) end |
Instance Attribute Details
#contract_amount ⇒ Object
Returns the value of attribute contract_amount.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 19 def contract_amount @contract_amount end |
#contract_code ⇒ Object
Returns the value of attribute contract_code.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 19 def contract_code @contract_code end |
#contract_percentage ⇒ Object
Returns the value of attribute contract_percentage.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 19 def contract_percentage @contract_percentage end |
#contract_type_code ⇒ '01', ...
Allowed Values are:
- '01' Diagnosis Related Group (DRG)
- '02' Per Diem
- '03' Variable Per Diem
- '04' Flat
- '05' Capitated
- '06' Percent
- '09' Other
33 34 35 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 33 def contract_type_code @contract_type_code end |
#contract_version_identifier ⇒ Object
Returns the value of attribute contract_version_identifier.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 19 def contract_version_identifier @contract_version_identifier end |
#terms_discount_percentage ⇒ Object
Returns the value of attribute terms_discount_percentage.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 19 def terms_discount_percentage @terms_discount_percentage end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 57 def self.attribute_map { contract_amount: :contractAmount, contract_code: :contractCode, contract_percentage: :contractPercentage, contract_type_code: :contractTypeCode, contract_version_identifier: :contractVersionIdentifier, terms_discount_percentage: :termsDiscountPercentage } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 69 def self.swagger_types { contract_amount: :String, contract_code: :String, contract_percentage: :String, contract_type_code: :String, contract_version_identifier: :String, terms_discount_percentage: :String } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && contract_amount == other.contract_amount && contract_code == other.contract_code && contract_percentage == other.contract_percentage && contract_type_code == other.contract_type_code && contract_version_identifier == other.contract_version_identifier && terms_discount_percentage == other.terms_discount_percentage end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 182 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = SwaggerClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 249 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 158 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) send("#{key}=", attributes[self.class.attribute_map[key]].map do |v| _deserialize(Regexp.last_match(1), v) end) end elsif !attributes[self.class.attribute_map[key]].nil? send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(other) ⇒ Boolean
144 145 146 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 144 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 153 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 150 def hash [contract_amount, contract_code, contract_percentage, contract_type_code, contract_version_identifier, terms_discount_percentage].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 103 def list_invalid_properties [] end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
228 229 230 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 228 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
222 223 224 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 222 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
109 110 111 112 113 114 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_contract_information.rb', line 109 def valid? contract_type_code_validator = EnumAttributeValidator.new('String', %w[01 02 03 04 05 06 09]) return false unless contract_type_code_validator.valid?(@contract_type_code) true end |