Class: ChangeHealthcare::ProfessionalClaims::SwaggerClient::ClaimInformation
- Inherits:
-
Object
- Object
- ChangeHealthcare::ProfessionalClaims::SwaggerClient::ClaimInformation
- Defined in:
- lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ambulance_certification ⇒ Object
Returns the value of attribute ambulance_certification.
-
#ambulance_drop_off_location ⇒ Object
Returns the value of attribute ambulance_drop_off_location.
-
#ambulance_pick_up_location ⇒ Object
Returns the value of attribute ambulance_pick_up_location.
-
#ambulance_transport_information ⇒ Object
Returns the value of attribute ambulance_transport_information.
-
#anesthesia_related_surgical_procedure ⇒ Object
Returns the value of attribute anesthesia_related_surgical_procedure.
-
#auto_accident_country_code ⇒ Object
Returns the value of attribute auto_accident_country_code.
-
#auto_accident_state_code ⇒ Object
Returns the value of attribute auto_accident_state_code.
-
#benefits_assignment_certification_indicator ⇒ Object
Allowed Values are:.
-
#claim_charge_amount ⇒ Object
Returns the value of attribute claim_charge_amount.
-
#claim_contract_information ⇒ Object
Returns the value of attribute claim_contract_information.
-
#claim_date_information ⇒ Object
Returns the value of attribute claim_date_information.
-
#claim_filing_code ⇒ Object
Returns the value of attribute claim_filing_code.
-
#claim_frequency_code ⇒ Object
Returns the value of attribute claim_frequency_code.
-
#claim_note ⇒ Object
Returns the value of attribute claim_note.
-
#claim_pricing_repricing_information ⇒ Object
Returns the value of attribute claim_pricing_repricing_information.
-
#claim_supplemental_information ⇒ Object
Returns the value of attribute claim_supplemental_information.
-
#condition_information ⇒ Object
Returns the value of attribute condition_information.
-
#delay_reason_code ⇒ Object
Allowed Values are:.
-
#epsdt_referral ⇒ Object
Returns the value of attribute epsdt_referral.
-
#file_information ⇒ Object
Returns the value of attribute file_information.
-
#health_care_code_information ⇒ Object
Returns the value of attribute health_care_code_information.
-
#homebound_indicator ⇒ Object
Returns the value of attribute homebound_indicator.
-
#other_subscriber_information ⇒ Object
Returns the value of attribute other_subscriber_information.
-
#patient_amount_paid ⇒ Object
Returns the value of attribute patient_amount_paid.
-
#patient_condition_information_vision ⇒ Object
Returns the value of attribute patient_condition_information_vision.
-
#patient_control_number ⇒ Object
Returns the value of attribute patient_control_number.
-
#patient_signature_source_code ⇒ Object
Returns the value of attribute patient_signature_source_code.
-
#patient_weight ⇒ Object
Returns the value of attribute patient_weight.
-
#place_of_service_code ⇒ Object
Returns the value of attribute place_of_service_code.
-
#plan_participation_code ⇒ Object
Allowed Values are:.
-
#property_casualty_claim_number ⇒ Object
Returns the value of attribute property_casualty_claim_number.
-
#related_causes_code ⇒ Object
readonly
Allowed Values are:.
-
#release_information_code ⇒ Object
Allowed Values are:.
-
#service_facility_location ⇒ Object
Returns the value of attribute service_facility_location.
-
#service_lines ⇒ Object
Returns the value of attribute service_lines.
-
#signature_indicator ⇒ Object
Allowed Values are:.
-
#special_program_code ⇒ Object
Allowed Values are:.
-
#spinal_manipulation_service_information ⇒ Object
Returns the value of attribute spinal_manipulation_service_information.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClaimInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ClaimInformation
Initializes the object
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 199 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.transform_keys(&:to_sym) if attributes.key?(:ambulanceCertification) && (value = attributes[:ambulanceCertification]).is_a?(Array) self.ambulance_certification = value end self.ambulance_drop_off_location = attributes[:ambulanceDropOffLocation] if attributes.key?(:ambulanceDropOffLocation) self.ambulance_pick_up_location = attributes[:ambulancePickUpLocation] if attributes.key?(:ambulancePickUpLocation) self.ambulance_transport_information = attributes[:ambulanceTransportInformation] if attributes.key?(:ambulanceTransportInformation) if attributes.key?(:anesthesiaRelatedSurgicalProcedure) && (value = attributes[:anesthesiaRelatedSurgicalProcedure]).is_a?(Array) self. = value end self.auto_accident_country_code = attributes[:autoAccidentCountryCode] if attributes.key?(:autoAccidentCountryCode) self.auto_accident_state_code = attributes[:autoAccidentStateCode] if attributes.key?(:autoAccidentStateCode) self.benefits_assignment_certification_indicator = attributes[:benefitsAssignmentCertificationIndicator] if attributes.key?(:benefitsAssignmentCertificationIndicator) self.claim_charge_amount = attributes[:claimChargeAmount] if attributes.key?(:claimChargeAmount) self.claim_contract_information = attributes[:claimContractInformation] if attributes.key?(:claimContractInformation) self.claim_date_information = attributes[:claimDateInformation] if attributes.key?(:claimDateInformation) self.claim_filing_code = attributes[:claimFilingCode] if attributes.key?(:claimFilingCode) self.claim_frequency_code = attributes[:claimFrequencyCode] if attributes.key?(:claimFrequencyCode) self.claim_note = attributes[:claimNote] if attributes.key?(:claimNote) self.claim_pricing_repricing_information = attributes[:claimPricingRepricingInformation] if attributes.key?(:claimPricingRepricingInformation) self.claim_supplemental_information = attributes[:claimSupplementalInformation] if attributes.key?(:claimSupplementalInformation) if attributes.key?(:conditionInformation) && (value = attributes[:conditionInformation]).is_a?(Array) self.condition_information = value end self.delay_reason_code = attributes[:delayReasonCode] if attributes.key?(:delayReasonCode) self.epsdt_referral = attributes[:epsdtReferral] if attributes.key?(:epsdtReferral) self.file_information = attributes[:fileInformation] if attributes.key?(:fileInformation) if attributes.key?(:healthCareCodeInformation) && (value = attributes[:healthCareCodeInformation]).is_a?(Array) self.health_care_code_information = value end self.homebound_indicator = attributes[:homeboundIndicator] if attributes.key?(:homeboundIndicator) if attributes.key?(:otherSubscriberInformation) && (value = attributes[:otherSubscriberInformation]).is_a?(Array) self.other_subscriber_information = value end self.patient_amount_paid = attributes[:patientAmountPaid] if attributes.key?(:patientAmountPaid) if attributes.key?(:patientConditionInformationVision) && (value = attributes[:patientConditionInformationVision]).is_a?(Array) self.patient_condition_information_vision = value end self.patient_control_number = attributes[:patientControlNumber] if attributes.key?(:patientControlNumber) self.patient_signature_source_code = attributes[:patientSignatureSourceCode] if attributes.key?(:patientSignatureSourceCode) self.patient_weight = attributes[:patientWeight] if attributes.key?(:patientWeight) self.place_of_service_code = attributes[:placeOfServiceCode] if attributes.key?(:placeOfServiceCode) self.plan_participation_code = attributes[:planParticipationCode] if attributes.key?(:planParticipationCode) self.property_casualty_claim_number = attributes[:propertyCasualtyClaimNumber] if attributes.key?(:propertyCasualtyClaimNumber) if attributes.key?(:relatedCausesCode) && (value = attributes[:relatedCausesCode]).is_a?(Array) self. = value end self.release_information_code = attributes[:releaseInformationCode] if attributes.key?(:releaseInformationCode) self.service_facility_location = attributes[:serviceFacilityLocation] if attributes.key?(:serviceFacilityLocation) if attributes.key?(:serviceLines) && (value = attributes[:serviceLines]).is_a?(Array) self.service_lines = value end self.signature_indicator = attributes[:signatureIndicator] if attributes.key?(:signatureIndicator) self.special_program_code = attributes[:specialProgramCode] if attributes.key?(:specialProgramCode) self.spinal_manipulation_service_information = attributes[:spinalManipulationServiceInformation] if attributes.key?(:spinalManipulationServiceInformation) end |
Instance Attribute Details
#ambulance_certification ⇒ Object
Returns the value of attribute ambulance_certification.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def ambulance_certification @ambulance_certification end |
#ambulance_drop_off_location ⇒ Object
Returns the value of attribute ambulance_drop_off_location.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def ambulance_drop_off_location @ambulance_drop_off_location end |
#ambulance_pick_up_location ⇒ Object
Returns the value of attribute ambulance_pick_up_location.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def ambulance_pick_up_location @ambulance_pick_up_location end |
#ambulance_transport_information ⇒ Object
Returns the value of attribute ambulance_transport_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def ambulance_transport_information @ambulance_transport_information end |
#anesthesia_related_surgical_procedure ⇒ Object
Returns the value of attribute anesthesia_related_surgical_procedure.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def end |
#auto_accident_country_code ⇒ Object
Returns the value of attribute auto_accident_country_code.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def auto_accident_country_code @auto_accident_country_code end |
#auto_accident_state_code ⇒ Object
Returns the value of attribute auto_accident_state_code.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def auto_accident_state_code @auto_accident_state_code end |
#benefits_assignment_certification_indicator ⇒ Object
Allowed Values are:
- 'N' No,
- 'W' Not Applicable - Use code 'W' when the patient refuses to assign benefits
- 'Y' Yes
36 37 38 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 36 def benefits_assignment_certification_indicator @benefits_assignment_certification_indicator end |
#claim_charge_amount ⇒ Object
Returns the value of attribute claim_charge_amount.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def claim_charge_amount @claim_charge_amount end |
#claim_contract_information ⇒ Object
Returns the value of attribute claim_contract_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def claim_contract_information @claim_contract_information end |
#claim_date_information ⇒ Object
Returns the value of attribute claim_date_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def claim_date_information @claim_date_information end |
#claim_filing_code ⇒ Object
Returns the value of attribute claim_filing_code.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def claim_filing_code @claim_filing_code end |
#claim_frequency_code ⇒ Object
Returns the value of attribute claim_frequency_code.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def claim_frequency_code @claim_frequency_code end |
#claim_note ⇒ Object
Returns the value of attribute claim_note.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def claim_note @claim_note end |
#claim_pricing_repricing_information ⇒ Object
Returns the value of attribute claim_pricing_repricing_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def claim_pricing_repricing_information @claim_pricing_repricing_information end |
#claim_supplemental_information ⇒ Object
Returns the value of attribute claim_supplemental_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def claim_supplemental_information @claim_supplemental_information end |
#condition_information ⇒ Object
Returns the value of attribute condition_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def condition_information @condition_information end |
#delay_reason_code ⇒ Object
Allowed Values are:
- '1' Proof of Eligibility Unknown or Unavailable
- '2' Litigation,
- '3' Authorization Delays
- '4' Delay in Certifying Provider
- '5' Delay in Supplying Billing Forms
- '6' Delay in Delivery of Custom-made Appliances,
- '7' Third Party Processing Delay
- '8' Delay in Eligibility Determination
- '9' Original Claim Rejected or Denied Due to a Reason Unrelated to the Billing Limitation Rules
- '10' Administration Delay in the Prior Approval Process
- '11' Other
- '15' Natural Disaster
52 53 54 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 52 def delay_reason_code @delay_reason_code end |
#epsdt_referral ⇒ Object
Returns the value of attribute epsdt_referral.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def epsdt_referral @epsdt_referral end |
#file_information ⇒ Object
Returns the value of attribute file_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def file_information @file_information end |
#health_care_code_information ⇒ Object
Returns the value of attribute health_care_code_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def health_care_code_information @health_care_code_information end |
#homebound_indicator ⇒ Object
Returns the value of attribute homebound_indicator.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def homebound_indicator @homebound_indicator end |
#other_subscriber_information ⇒ Object
Returns the value of attribute other_subscriber_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def other_subscriber_information @other_subscriber_information end |
#patient_amount_paid ⇒ Object
Returns the value of attribute patient_amount_paid.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def patient_amount_paid @patient_amount_paid end |
#patient_condition_information_vision ⇒ Object
Returns the value of attribute patient_condition_information_vision.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def patient_condition_information_vision @patient_condition_information_vision end |
#patient_control_number ⇒ Object
Returns the value of attribute patient_control_number.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def patient_control_number @patient_control_number end |
#patient_signature_source_code ⇒ Object
Returns the value of attribute patient_signature_source_code.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def patient_signature_source_code @patient_signature_source_code end |
#patient_weight ⇒ Object
Returns the value of attribute patient_weight.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def patient_weight @patient_weight end |
#place_of_service_code ⇒ Object
Returns the value of attribute place_of_service_code.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def place_of_service_code @place_of_service_code end |
#plan_participation_code ⇒ Object
Allowed Values are:
- 'A' Assigned
- 'B' Assignment Accepted on Clinical Lab Service Only
- 'C' Not Assigned - Required when neither codes 'A' or 'B' apply
59 60 61 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 59 def plan_participation_code @plan_participation_code end |
#property_casualty_claim_number ⇒ Object
Returns the value of attribute property_casualty_claim_number.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def property_casualty_claim_number @property_casualty_claim_number end |
#related_causes_code ⇒ Object (readonly)
Allowed Values are:
- 'AA' Auto Accident
- 'EM' Employment
- 'OA' Other Accident
66 67 68 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 66 def end |
#release_information_code ⇒ Object
Allowed Values are:
- 'I' Informed Consent to Release Medical Information for Conditions or Diagnoses Regulated by Federal Statutes
- 'Y' Yes
72 73 74 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 72 def release_information_code @release_information_code end |
#service_facility_location ⇒ Object
Returns the value of attribute service_facility_location.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def service_facility_location @service_facility_location end |
#service_lines ⇒ Object
Returns the value of attribute service_lines.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def service_lines @service_lines end |
#signature_indicator ⇒ Object
Allowed Values are:
- 'N' NO,
- 'Y' Yes
78 79 80 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 78 def signature_indicator @signature_indicator end |
#special_program_code ⇒ Object
Allowed Values are:
- '02' Physically Handicapped Children's Program
- '03' Special Federal Funding
- '05' Disabolity
- '09' Second Opinion or Surgery
86 87 88 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 86 def special_program_code @special_program_code end |
#spinal_manipulation_service_information ⇒ Object
Returns the value of attribute spinal_manipulation_service_information.
19 20 21 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 19 def spinal_manipulation_service_information @spinal_manipulation_service_information end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 110 def self.attribute_map { ambulance_certification: :ambulanceCertification, ambulance_drop_off_location: :ambulanceDropOffLocation, ambulance_pick_up_location: :ambulancePickUpLocation, ambulance_transport_information: :ambulanceTransportInformation, anesthesia_related_surgical_procedure: :anesthesiaRelatedSurgicalProcedure, auto_accident_country_code: :autoAccidentCountryCode, auto_accident_state_code: :autoAccidentStateCode, benefits_assignment_certification_indicator: :benefitsAssignmentCertificationIndicator, claim_charge_amount: :claimChargeAmount, claim_contract_information: :claimContractInformation, claim_date_information: :claimDateInformation, claim_filing_code: :claimFilingCode, claim_frequency_code: :claimFrequencyCode, claim_note: :claimNote, claim_pricing_repricing_information: :claimPricingRepricingInformation, claim_supplemental_information: :claimSupplementalInformation, condition_information: :conditionInformation, delay_reason_code: :delayReasonCode, epsdt_referral: :epsdtReferral, file_information: :fileInformation, health_care_code_information: :healthCareCodeInformation, homebound_indicator: :homeboundIndicator, other_subscriber_information: :otherSubscriberInformation, patient_amount_paid: :patientAmountPaid, patient_condition_information_vision: :patientConditionInformationVision, patient_control_number: :patientControlNumber, patient_signature_source_code: :patientSignatureSourceCode, patient_weight: :patientWeight, place_of_service_code: :placeOfServiceCode, plan_participation_code: :planParticipationCode, property_casualty_claim_number: :propertyCasualtyClaimNumber, related_causes_code: :relatedCausesCode, release_information_code: :releaseInformationCode, service_facility_location: :serviceFacilityLocation, service_lines: :serviceLines, signature_indicator: :signatureIndicator, special_program_code: :specialProgramCode, spinal_manipulation_service_information: :spinalManipulationServiceInformation } end |
.swagger_types ⇒ Object
Attribute type mapping.
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 154 def self.swagger_types { ambulance_certification: :'Array<AmbulanceCertification>', ambulance_drop_off_location: :Address, ambulance_pick_up_location: :Address, ambulance_transport_information: :AmbulanceTransportInformation, anesthesia_related_surgical_procedure: :'Array<String>', auto_accident_country_code: :String, auto_accident_state_code: :String, benefits_assignment_certification_indicator: :String, claim_charge_amount: :String, claim_contract_information: :ClaimContractInformation, claim_date_information: :ClaimDateInformation, claim_filing_code: :String, claim_frequency_code: :String, claim_note: :ClaimNote, claim_pricing_repricing_information: :ClaimPricingRepricingInformation, claim_supplemental_information: :ClaimSupplementalInformation, condition_information: :'Array<ConditionInformation>', delay_reason_code: :String, epsdt_referral: :EpsdtReferral, file_information: :String, health_care_code_information: :'Array<HealthCareInformation>', homebound_indicator: :BOOLEAN, other_subscriber_information: :'Array<OtherSubscriberInformation>', patient_amount_paid: :String, patient_condition_information_vision: :'Array<PatientConditionInformationVision>', patient_control_number: :String, patient_signature_source_code: :BOOLEAN, patient_weight: :String, place_of_service_code: :String, plan_participation_code: :String, property_casualty_claim_number: :String, related_causes_code: :'Array<String>', release_information_code: :String, service_facility_location: :ServiceFacilityLocation, service_lines: :'Array<ServiceLine>', signature_indicator: :String, special_program_code: :String, spinal_manipulation_service_information: :SpinalManipulationServiceInformation } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 403 def ==(other) return true if equal?(other) self.class == other.class && ambulance_certification == other.ambulance_certification && ambulance_drop_off_location == other.ambulance_drop_off_location && ambulance_pick_up_location == other.ambulance_pick_up_location && ambulance_transport_information == other.ambulance_transport_information && == other. && auto_accident_country_code == other.auto_accident_country_code && auto_accident_state_code == other.auto_accident_state_code && benefits_assignment_certification_indicator == other.benefits_assignment_certification_indicator && claim_charge_amount == other.claim_charge_amount && claim_contract_information == other.claim_contract_information && claim_date_information == other.claim_date_information && claim_filing_code == other.claim_filing_code && claim_frequency_code == other.claim_frequency_code && claim_note == other.claim_note && claim_pricing_repricing_information == other.claim_pricing_repricing_information && claim_supplemental_information == other.claim_supplemental_information && condition_information == other.condition_information && delay_reason_code == other.delay_reason_code && epsdt_referral == other.epsdt_referral && file_information == other.file_information && health_care_code_information == other.health_care_code_information && homebound_indicator == other.homebound_indicator && other_subscriber_information == other.other_subscriber_information && patient_amount_paid == other.patient_amount_paid && patient_condition_information_vision == other.patient_condition_information_vision && patient_control_number == other.patient_control_number && patient_signature_source_code == other.patient_signature_source_code && patient_weight == other.patient_weight && place_of_service_code == other.place_of_service_code && plan_participation_code == other.plan_participation_code && property_casualty_claim_number == other.property_casualty_claim_number && == other. && release_information_code == other.release_information_code && service_facility_location == other.service_facility_location && service_lines == other.service_lines && signature_indicator == other.signature_indicator && special_program_code == other.special_program_code && spinal_manipulation_service_information == other.spinal_manipulation_service_information end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 496 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = SwaggerClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
563 564 565 566 567 568 569 570 571 572 573 574 575 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 563 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 472 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) send("#{key}=", attributes[self.class.attribute_map[key]].map do |v| _deserialize(Regexp.last_match(1), v) end) end elsif !attributes[self.class.attribute_map[key]].nil? send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(other) ⇒ Boolean
449 450 451 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 449 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 455 def hash [ ambulance_certification, ambulance_drop_off_location, ambulance_pick_up_location, ambulance_transport_information, , auto_accident_country_code, auto_accident_state_code, benefits_assignment_certification_indicator, claim_charge_amount, claim_contract_information, claim_date_information, claim_filing_code, claim_frequency_code, claim_note, claim_pricing_repricing_information, claim_supplemental_information, condition_information, delay_reason_code, epsdt_referral, file_information, health_care_code_information, homebound_indicator, other_subscriber_information, patient_amount_paid, patient_condition_information_vision, patient_control_number, patient_signature_source_code, patient_weight, place_of_service_code, plan_participation_code, property_casualty_claim_number, , release_information_code, service_facility_location, service_lines, signature_indicator, special_program_code, spinal_manipulation_service_information ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
300 301 302 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 300 def list_invalid_properties [] end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
542 543 544 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 542 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
548 549 550 551 552 553 554 555 556 557 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 548 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
536 537 538 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 536 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/claim_information.rb', line 306 def valid? benefits_assignment_certification_indicator_validator = EnumAttributeValidator.new('String', %w[N W Y]) return false unless benefits_assignment_certification_indicator_validator.valid?(@benefits_assignment_certification_indicator) delay_reason_code_validator = EnumAttributeValidator.new('String', %w[1 2 3 4 5 6 7 8 9 10 11 15]) return false unless delay_reason_code_validator.valid?(@delay_reason_code) plan_participation_code_validator = EnumAttributeValidator.new('String', %w[A B C]) return false unless plan_participation_code_validator.valid?(@plan_participation_code) release_information_code_validator = EnumAttributeValidator.new('String', %w[I Y]) return false unless release_information_code_validator.valid?(@release_information_code) signature_indicator_validator = EnumAttributeValidator.new('String', %w[N Y]) return false unless signature_indicator_validator.valid?(@signature_indicator) special_program_code_validator = EnumAttributeValidator.new('String', %w[02 03 05 09]) return false unless special_program_code_validator.valid?(@special_program_code) true end |