Class: ChangeHealthcare::ProfessionalClaims::SwaggerClient::DrugIdentification
- Inherits:
-
Object
- Object
- ChangeHealthcare::ProfessionalClaims::SwaggerClient::DrugIdentification
- Defined in:
- lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#link_sequence_number ⇒ Object
Can only set one of linkSequenceNumber and pharmacyPrescriptionNumber but not both.
-
#measurement_unit_code ⇒ Object
Allowed Values are:'F2' International Unit, 'GR' Gram, 'ME' Milligram, 'ML' Milliliter, 'UN' Unit.
-
#national_drug_code ⇒ Object
Returns the value of attribute national_drug_code.
-
#national_drug_unit_count ⇒ Object
Returns the value of attribute national_drug_unit_count.
-
#pharmacy_prescription_number ⇒ Object
Can only set one of linkSequenceNumber and pharmacyPrescriptionNumber but not both.
-
#service_id_qualifier ⇒ Object
Allowed Values are:'EN' EAN/UCC - 13, 'EO' EAN/UCC - 8, 'HI' HIBC (Health Care Industry Bar Code) Supplier Labeling Standard Primary Data Message, 'N4' National Drug Code in 5-4-2 Format, 'ON' Customer Order Number, 'UK' GTIN 14-digit Data Structure, 'UP' UCC - 12.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DrugIdentification
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DrugIdentification
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.transform_keys(&:to_sym) self.link_sequence_number = attributes[:linkSequenceNumber] if attributes.key?(:linkSequenceNumber) self.measurement_unit_code = attributes[:measurementUnitCode] if attributes.key?(:measurementUnitCode) self.national_drug_code = attributes[:nationalDrugCode] if attributes.key?(:nationalDrugCode) self.national_drug_unit_count = attributes[:nationalDrugUnitCount] if attributes.key?(:nationalDrugUnitCount) self.pharmacy_prescription_number = attributes[:pharmacyPrescriptionNumber] if attributes.key?(:pharmacyPrescriptionNumber) self.service_id_qualifier = attributes[:serviceIdQualifier] if attributes.key?(:serviceIdQualifier) end |
Instance Attribute Details
#link_sequence_number ⇒ Object
Can only set one of linkSequenceNumber and pharmacyPrescriptionNumber but not both
20 21 22 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 20 def link_sequence_number @link_sequence_number end |
#measurement_unit_code ⇒ Object
Allowed Values are:'F2' International Unit, 'GR' Gram, 'ME' Milligram, 'ML' Milliliter, 'UN' Unit
23 24 25 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 23 def measurement_unit_code @measurement_unit_code end |
#national_drug_code ⇒ Object
Returns the value of attribute national_drug_code.
25 26 27 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 25 def national_drug_code @national_drug_code end |
#national_drug_unit_count ⇒ Object
Returns the value of attribute national_drug_unit_count.
25 26 27 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 25 def national_drug_unit_count @national_drug_unit_count end |
#pharmacy_prescription_number ⇒ Object
Can only set one of linkSequenceNumber and pharmacyPrescriptionNumber but not both
28 29 30 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 28 def pharmacy_prescription_number @pharmacy_prescription_number end |
#service_id_qualifier ⇒ Object
Allowed Values are:'EN' EAN/UCC - 13, 'EO' EAN/UCC - 8, 'HI' HIBC (Health Care Industry Bar Code) Supplier Labeling Standard Primary Data Message, 'N4' National Drug Code in 5-4-2 Format, 'ON' Customer Order Number, 'UK' GTIN 14-digit Data Structure, 'UP' UCC - 12
31 32 33 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 31 def service_id_qualifier @service_id_qualifier end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 55 def self.attribute_map { link_sequence_number: :linkSequenceNumber, measurement_unit_code: :measurementUnitCode, national_drug_code: :nationalDrugCode, national_drug_unit_count: :nationalDrugUnitCount, pharmacy_prescription_number: :pharmacyPrescriptionNumber, service_id_qualifier: :serviceIdQualifier } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 67 def self.swagger_types { link_sequence_number: :String, measurement_unit_code: :String, national_drug_code: :String, national_drug_unit_count: :String, pharmacy_prescription_number: :String, service_id_qualifier: :String } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 143 def ==(other) return true if equal?(other) self.class == other.class && link_sequence_number == other.link_sequence_number && measurement_unit_code == other.measurement_unit_code && national_drug_code == other.national_drug_code && national_drug_unit_count == other.national_drug_unit_count && pharmacy_prescription_number == other.pharmacy_prescription_number && service_id_qualifier == other.service_id_qualifier end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 195 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = SwaggerClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 262 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 171 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) send("#{key}=", attributes[self.class.attribute_map[key]].map do |v| _deserialize(Regexp.last_match(1), v) end) end elsif !attributes[self.class.attribute_map[key]].nil? send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(other) ⇒ Boolean
157 158 159 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 157 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
163 164 165 166 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 163 def hash [link_sequence_number, measurement_unit_code, national_drug_code, national_drug_unit_count, pharmacy_prescription_number, service_id_qualifier].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
101 102 103 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 101 def list_invalid_properties [] end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
241 242 243 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 241 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
235 236 237 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 235 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
107 108 109 110 111 112 113 114 115 |
# File 'lib/change_healthcare/professional_claims/swagger_client/models/drug_identification.rb', line 107 def valid? measurement_unit_code_validator = EnumAttributeValidator.new('String', %w[F2 GR ME ML UN]) return false unless measurement_unit_code_validator.valid?(@measurement_unit_code) service_id_qualifier_validator = EnumAttributeValidator.new('String', %w[EN EO HI N4 ON UK UP]) return false unless service_id_qualifier_validator.valid?(@service_id_qualifier) true end |